@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
-# License: http://snmplabs.com/pysnmp/license.html
+# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# License: https://www.pysnmp.com/pysnmp/license.html
 #
 from pysnmp.proto import rfc1905, rfc3411, error
 from pysnmp.proto.api import v1, v2c
@@ -19,7 +19,7 @@ __v1ToV2ValueMap = {
     v1.Counter.tagSet: v2c.Counter32(),
     v1.Gauge.tagSet: v2c.Gauge32(),
     v1.TimeTicks.tagSet: v2c.TimeTicks(),
-    v1.Opaque.tagSet: v2c.Opaque()
+    v1.Opaque.tagSet: v2c.Opaque(),
 }
 
 __v2ToV1ValueMap = {  # XXX do not re-create same-type items?
@@ -31,7 +31,7 @@ __v2ToV1ValueMap = {  # XXX do not re-create same-type items?
     v2c.Counter32.tagSet: v1.Counter(),
     v2c.Gauge32.tagSet: v1.Gauge(),
     v2c.TimeTicks.tagSet: v1.TimeTicks(),
-    v2c.Opaque.tagSet: v1.Opaque()
+    v2c.Opaque.tagSet: v1.Opaque(),
 }
 
 # PDU map
@@ -41,7 +41,7 @@ __v1ToV2PduMap = {
     v1.GetNextRequestPDU.tagSet: v2c.GetNextRequestPDU(),
     v1.SetRequestPDU.tagSet: v2c.SetRequestPDU(),
     v1.GetResponsePDU.tagSet: v2c.ResponsePDU(),
-    v1.TrapPDU.tagSet: v2c.SNMPv2TrapPDU()
+    v1.TrapPDU.tagSet: v2c.SNMPv2TrapPDU(),
 }
 
 __v2ToV1PduMap = {
@@ -50,7 +50,7 @@ __v2ToV1PduMap = {
     v2c.SetRequestPDU.tagSet: v1.SetRequestPDU(),
     v2c.ResponsePDU.tagSet: v1.GetResponsePDU(),
     v2c.SNMPv2TrapPDU.tagSet: v1.TrapPDU(),
-    v2c.GetBulkRequestPDU.tagSet: v1.GetNextRequestPDU()  # 4.1.1
+    v2c.GetBulkRequestPDU.tagSet: v1.GetNextRequestPDU(),  # 4.1.1
 }
 
 # Trap map
@@ -61,7 +61,7 @@ __v1ToV2TrapMap = {
     2: (1, 3, 6, 1, 6, 3, 1, 1, 5, 3),
     3: (1, 3, 6, 1, 6, 3, 1, 1, 5, 4),
     4: (1, 3, 6, 1, 6, 3, 1, 1, 5, 5),
-    5: (1, 3, 6, 1, 6, 3, 1, 1, 5, 6)
+    5: (1, 3, 6, 1, 6, 3, 1, 1, 5, 6),
 }
 
 __v2ToV1TrapMap = {
@@ -70,7 +70,7 @@ __v2ToV1TrapMap = {
     (1, 3, 6, 1, 6, 3, 1, 1, 5, 3): 2,
     (1, 3, 6, 1, 6, 3, 1, 1, 5, 4): 3,
     (1, 3, 6, 1, 6, 3, 1, 1, 5, 5): 4,
-    (1, 3, 6, 1, 6, 3, 1, 1, 5, 6): 5
+    (1, 3, 6, 1, 6, 3, 1, 1, 5, 6): 5,
 }
 
 # 4.3
@@ -91,17 +91,19 @@ __v2ToV1ErrorMap = {
     13: 5,
     14: 5,
     15: 5,
-    16: 2
+    16: 2,
 }
 
 __zeroInt = v1.Integer(0)
 
 
-def v1ToV2(v1Pdu, origV2Pdu=None, snmpTrapCommunity=''):
+def v1ToV2(v1Pdu, origV2Pdu=None, snmpTrapCommunity=""):
     pduType = v1Pdu.tagSet
     v2Pdu = __v1ToV2PduMap[pduType].clone()
 
-    debug.logger & debug.flagPrx and debug.logger('v1ToV2: v1Pdu %s' % v1Pdu.prettyPrint())
+    debug.logger & debug.flagPrx and debug.logger(
+        "v1ToV2: v1Pdu %s" % v1Pdu.prettyPrint()
+    )
 
     v2VarBinds = []
 
@@ -113,7 +115,10 @@ def v1ToV2(v1Pdu, origV2Pdu=None, snmpTrapCommunity=''):
         # 3.1.2
         genericTrap = v1.apiTrapPDU.getGenericTrap(v1Pdu)
         if genericTrap == 6:
-            snmpTrapOIDParam = v1.apiTrapPDU.getEnterprise(v1Pdu) + (0, int(v1.apiTrapPDU.getSpecificTrap(v1Pdu)))
+            snmpTrapOIDParam = v1.apiTrapPDU.getEnterprise(v1Pdu) + (
+                0,
+                int(v1.apiTrapPDU.getSpecificTrap(v1Pdu)),
+            )
 
         # 3.1.3
         else:
@@ -125,9 +130,12 @@ def v1ToV2(v1Pdu, origV2Pdu=None, snmpTrapCommunity=''):
         v2VarBinds.append(
             (v2c.apiTrapPDU.snmpTrapAddress, v1.apiTrapPDU.getAgentAddr(v1Pdu))
         )
-        v2VarBinds.append((v2c.apiTrapPDU.snmpTrapCommunity, v2c.OctetString(snmpTrapCommunity)))
-        v2VarBinds.append((v2c.apiTrapPDU.snmpTrapEnterprise,
-                           v1.apiTrapPDU.getEnterprise(v1Pdu)))
+        v2VarBinds.append(
+            (v2c.apiTrapPDU.snmpTrapCommunity, v2c.OctetString(snmpTrapCommunity))
+        )
+        v2VarBinds.append(
+            (v2c.apiTrapPDU.snmpTrapEnterprise, v1.apiTrapPDU.getEnterprise(v1Pdu))
+        )
 
         varBinds = v1.apiTrapPDU.getVarBinds(v1Pdu)
     else:
@@ -138,9 +146,7 @@ def v1ToV2(v1Pdu, origV2Pdu=None, snmpTrapCommunity=''):
         # 2.1.1.11
         if v1Val.tagSet == v1.NetworkAddress.tagSet:
             v1Val = v1Val.getComponent()
-        v2VarBinds.append(
-            (oid, __v1ToV2ValueMap[v1Val.tagSet].clone(v1Val))
-        )
+        v2VarBinds.append((oid, __v1ToV2ValueMap[v1Val.tagSet].clone(v1Val)))
 
     if pduType not in rfc3411.notificationClassPDUs:
         errorStatus = int(v1.apiPDU.getErrorStatus(v1Pdu))
@@ -167,20 +173,24 @@ def v1ToV2(v1Pdu, origV2Pdu=None, snmpTrapCommunity=''):
 
     v2c.apiPDU.setVarBinds(v2Pdu, v2VarBinds)
 
-    debug.logger & debug.flagPrx and debug.logger('v1ToV2: v2Pdu %s' % v2Pdu.prettyPrint())
+    debug.logger & debug.flagPrx and debug.logger(
+        "v1ToV2: v2Pdu %s" % v2Pdu.prettyPrint()
+    )
 
     return v2Pdu
 
 
 def v2ToV1(v2Pdu, origV1Pdu=None):
-    debug.logger & debug.flagPrx and debug.logger('v2ToV1: v2Pdu %s' % v2Pdu.prettyPrint())
+    debug.logger & debug.flagPrx and debug.logger(
+        "v2ToV1: v2Pdu %s" % v2Pdu.prettyPrint()
+    )
 
     pduType = v2Pdu.tagSet
 
     if pduType in __v2ToV1PduMap:
         v1Pdu = __v2ToV1PduMap[pduType].clone()
     else:
-        raise error.ProtocolError('Unsupported PDU type')
+        raise error.ProtocolError("Unsupported PDU type")
 
     v2VarBinds = v2c.apiPDU.getVarBinds(v2Pdu)
     v1VarBinds = []
@@ -190,7 +200,7 @@ def v2ToV1(v2Pdu, origV1Pdu=None):
         # 3.2.1
         snmpTrapOID, snmpTrapOIDParam = v2VarBinds[1]
         if snmpTrapOID != v2c.apiTrapPDU.snmpTrapOID:
-            raise error.ProtocolError('Second OID not snmpTrapOID')
+            raise error.ProtocolError("Second OID not snmpTrapOID")
         snmpTrapOID, snmpTrapOIDParam = v2VarBinds[1]
         if snmpTrapOIDParam in __v2ToV1TrapMap:
             for oid, val in v2VarBinds:
@@ -210,10 +220,12 @@ def v2ToV1(v2Pdu, origV1Pdu=None):
         for oid, val in v2VarBinds:
             # snmpTrapAddress
             if oid == v2c.apiTrapPDU.snmpTrapAddress:
-                v1.apiTrapPDU.setAgentAddr(v1Pdu, v1.IpAddress(val))  # v2c.OctetString is more constrained
+                v1.apiTrapPDU.setAgentAddr(
+                    v1Pdu, v1.IpAddress(val)
+                )  # v2c.OctetString is more constrained
                 break
         else:
-            v1.apiTrapPDU.setAgentAddr(v1Pdu, v1.IpAddress('0.0.0.0'))
+            v1.apiTrapPDU.setAgentAddr(v1Pdu, v1.IpAddress("0.0.0.0"))
 
         # 3.2.3
         if snmpTrapOIDParam in __v2ToV1TrapMap:
@@ -232,10 +244,11 @@ def v2ToV1(v2Pdu, origV1Pdu=None):
 
         __v2VarBinds = []
         for oid, val in v2VarBinds[2:]:
-            if oid in __v2ToV1TrapMap or \
-                    oid in (v2c.apiTrapPDU.sysUpTime,
-                            v2c.apiTrapPDU.snmpTrapAddress,
-                            v2c.apiTrapPDU.snmpTrapEnterprise):
+            if oid in __v2ToV1TrapMap or oid in (
+                v2c.apiTrapPDU.sysUpTime,
+                v2c.apiTrapPDU.snmpTrapAddress,
+                v2c.apiTrapPDU.snmpTrapEnterprise,
+            ):
                 continue
             __v2VarBinds.append((oid, val))
         v2VarBinds = __v2VarBinds
@@ -259,12 +272,14 @@ def v2ToV1(v2Pdu, origV1Pdu=None):
                 elif origV1Pdu.tagSet == v1.GetNextRequestPDU.tagSet:
                     raise error.StatusInformation(idx=idx, pdu=v2Pdu)
                 else:
-                    raise error.ProtocolError('Counter64 on the way')
+                    raise error.ProtocolError("Counter64 on the way")
 
             # 4.1.2.2.1&2
-            if val.tagSet in (v2c.NoSuchObject.tagSet,
-                              v2c.NoSuchInstance.tagSet,
-                              v2c.EndOfMibView.tagSet):
+            if val.tagSet in (
+                v2c.NoSuchObject.tagSet,
+                v2c.NoSuchInstance.tagSet,
+                v2c.EndOfMibView.tagSet,
+            ):
                 v1.apiPDU.setErrorStatus(v1Pdu, 2)
                 v1.apiPDU.setErrorIndex(v1Pdu, idx + 1)
 
@@ -273,34 +288,31 @@ def v2ToV1(v2Pdu, origV1Pdu=None):
         # 4.1.2.3.1
         v2ErrorStatus = v2c.apiPDU.getErrorStatus(v2Pdu)
         if v2ErrorStatus:
-            v1.apiPDU.setErrorStatus(
-                v1Pdu, __v2ToV1ErrorMap.get(v2ErrorStatus, 5)
+            v1.apiPDU.setErrorStatus(v1Pdu, __v2ToV1ErrorMap.get(v2ErrorStatus, 5))
+            v1.apiPDU.setErrorIndex(
+                v1Pdu, v2c.apiPDU.getErrorIndex(v2Pdu, muteErrors=True)
             )
-            v1.apiPDU.setErrorIndex(v1Pdu, v2c.apiPDU.getErrorIndex(v2Pdu, muteErrors=True))
 
     elif pduType in rfc3411.confirmedClassPDUs:
         v1.apiPDU.setErrorStatus(v1Pdu, 0)
         v1.apiPDU.setErrorIndex(v1Pdu, 0)
 
     # Translate Var-Binds
-    if (pduType in rfc3411.responseClassPDUs and
-            v1.apiPDU.getErrorStatus(v1Pdu)):
+    if pduType in rfc3411.responseClassPDUs and v1.apiPDU.getErrorStatus(v1Pdu):
         v1VarBinds = v1.apiPDU.getVarBinds(origV1Pdu)
     else:
         for oid, v2Val in v2VarBinds:
-            v1VarBinds.append(
-                (oid, __v2ToV1ValueMap[v2Val.tagSet].clone(v2Val))
-            )
+            v1VarBinds.append((oid, __v2ToV1ValueMap[v2Val.tagSet].clone(v2Val)))
 
     if pduType in rfc3411.notificationClassPDUs:
         v1.apiTrapPDU.setVarBinds(v1Pdu, v1VarBinds)
     else:
         v1.apiPDU.setVarBinds(v1Pdu, v1VarBinds)
 
-        v1.apiPDU.setRequestID(
-            v1Pdu, v2c.apiPDU.getRequestID(v2Pdu)
-        )
+        v1.apiPDU.setRequestID(v1Pdu, v2c.apiPDU.getRequestID(v2Pdu))
 
-    debug.logger & debug.flagPrx and debug.logger('v2ToV1: v1Pdu %s' % v1Pdu.prettyPrint())
+    debug.logger & debug.flagPrx and debug.logger(
+        "v2ToV1: v1Pdu %s" % v1Pdu.prettyPrint()
+    )
 
     return v1Pdu
