@@ -1,8 +1,8 @@
 #
 # This file is part of pysnmp software.
 #
-# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
-# License: http://snmplabs.com/pysnmp/license.html
+# Copyright (c) 2005-2020, Ilya Etingof <etingof@gmail.com>
+# License: https://www.pysnmp.com/pysnmp/license.html
 #
 from pysnmp.proto.secmod.rfc3826.priv import aes
 from pysnmp.proto.secmod.rfc3414.auth import hmacmd5, hmacsha
@@ -34,18 +34,17 @@ class AbstractAesBlumenthal(aes.Aes):
         elif authProtocol in hmacsha2.HmacSha2.hashAlgorithms:
             hashAlgo = hmacsha2.HmacSha2.hashAlgorithms[authProtocol]
         else:
-            raise error.ProtocolError(
-                'Unknown auth protocol %s' % (authProtocol,)
-            )
+            raise error.ProtocolError(f"Unknown auth protocol {authProtocol}")
 
         localPrivKey = localkey.localizeKey(privKey, snmpEngineID, hashAlgo)
 
         # now extend this key if too short by repeating steps that includes the hashPassphrase step
         for count in range(1, int(ceil(self.keySize * 1.0 / len(localPrivKey)))):
             localPrivKey += localPrivKey.clone(
-                hashAlgo(localPrivKey.asOctets()).digest())
+                hashAlgo(localPrivKey.asOctets()).digest()
+            )
 
-        return localPrivKey[:self.keySize]
+        return localPrivKey[: self.keySize]
 
 
 class AbstractAesReeder(aes.Aes):
@@ -63,6 +62,7 @@ class AbstractAesReeder(aes.Aes):
     The difference between the two is that the Reeder draft does key extension by repeating
     the steps in the password to key algorithm (hash phrase, then localize with SNMPEngine ID).
     """
+
     serviceID = ()
     keySize = 0
 
@@ -75,9 +75,7 @@ class AbstractAesReeder(aes.Aes):
         elif authProtocol in hmacsha2.HmacSha2.hashAlgorithms:
             hashAlgo = hmacsha2.HmacSha2.hashAlgorithms[authProtocol]
         else:
-            raise error.ProtocolError(
-                'Unknown auth protocol %s' % (authProtocol,)
-            )
+            raise error.ProtocolError(f"Unknown auth protocol {authProtocol}")
 
         localPrivKey = localkey.localizeKey(privKey, snmpEngineID, hashAlgo)
 
@@ -87,4 +85,4 @@ class AbstractAesReeder(aes.Aes):
             newKey = localkey.hashPassphrase(localPrivKey, hashAlgo)
             localPrivKey += localkey.localizeKey(newKey, snmpEngineID, hashAlgo)
 
-        return localPrivKey[:self.keySize]
+        return localPrivKey[: self.keySize]
